@@ -5,15 +5,13 @@ use warnings;
 use Carp;
 
 use AnyEvent;
+use Coro;
 use Coro::AnyEvent qw(sleep);
 use Coro::Channel;
 use Coro::ProcessPool::Process;
-use Coro::Storable qw(freeze thaw);
-use Coro;
-use MIME::Base64 qw(encode_base64 decode_base64);
 use Sys::Info;
 
-our $VERSION = 0.12;
+our $VERSION = '0.13';
 
 if ($^O eq 'MSWin32') {
     die 'MSWin32 is not supported';
@@ -21,21 +19,14 @@ if ($^O eq 'MSWin32') {
 
 our $CPU_COUNT = _cpu_count();
 
-use fields qw(
-    max_procs
-    num_procs
-    max_reqs
-    procs
-);
-
 sub new {
     my ($class, %param) = @_;
-    my $self = fields::new($class);
-    $self->{max_procs} = $param{max_procs} || $CPU_COUNT;
-    $self->{max_reqs}  = $param{max_reqs}  || 0;
-    $self->{num_procs} = 0;
-    $self->{procs}     = Coro::Channel->new();
-    return $self;
+    return bless {
+        max_procs => $param{max_procs} || $CPU_COUNT,
+        max_reqs  => $param{max_reqs}  || 0,
+        num_procs => 0,
+        procs     => Coro::Channel->new(),
+    }, $class;
 }
 
 sub _cpu_count {
